summaryrefslogtreecommitdiffstats
path: root/chrome/browser/renderer_host/cross_site_resource_handler.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/renderer_host/cross_site_resource_handler.cc
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/renderer_host/cross_site_resource_handler.cc')
-rw-r--r--chrome/browser/renderer_host/cross_site_resource_handler.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/chrome/browser/renderer_host/cross_site_resource_handler.cc b/chrome/browser/renderer_host/cross_site_resource_handler.cc
index 1e25f17..5064a34 100644
--- a/chrome/browser/renderer_host/cross_site_resource_handler.cc
+++ b/chrome/browser/renderer_host/cross_site_resource_handler.cc
@@ -8,11 +8,11 @@
#include "chrome/browser/renderer_host/render_view_host.h"
#include "chrome/browser/tab_contents/tab_util.h"
-#include "chrome/browser/tab_contents/web_contents.h"
+#include "chrome/browser/tab_contents/tab_contents.h"
namespace {
// Task to notify the WebContents that a cross-site response has begun, so that
// WebContents can tell the old page to run its onunload handler.
class CrossSiteNotifyTabTask : public Task {
public:
CrossSiteNotifyTabTask(int render_process_host_id,
@@ -48,10 +48,10 @@ class CancelPendingRenderViewTask : public Task {
render_view_id_(render_view_id) {}
void Run() {
- WebContents* web_contents =
- tab_util::GetWebContentsByID(render_process_host_id_, render_view_id_);
- if (web_contents)
- web_contents->CrossSiteNavigationCanceled();
+ TabContents* tab_contents =
+ tab_util::GetTabContentsByID(render_process_host_id_, render_view_id_);
+ if (tab_contents)
+ tab_contents->CrossSiteNavigationCanceled();
}
private:
@@ -174,7 +174,7 @@ bool CrossSiteResourceHandler::OnResponseCompleted(
}
// We can now send the response to the new renderer, which will cause
// WebContents to swap in the new renderer and destroy the old one.
void CrossSiteResourceHandler::ResumeResponse() {
DCHECK(request_id_ != -1);
DCHECK(in_cross_site_transition_);
@@ -8,11 +8,11 @@
namespace {
-// Task to notify the WebContents that a cross-site response has begun, so that
-// WebContents can tell the old page to run its onunload handler.
+// Task to notify the TabContents that a cross-site response has begun, so that
+// TabContents can tell the old page to run its onunload handler.
class CrossSiteNotifyTabTask : public Task {
public:
@@ -174,7 +174,7 @@ bool CrossSiteResourceHandler::OnResponseCompleted(
}
// We can now send the response to the new renderer, which will cause
-// WebContents to swap in the new renderer and destroy the old one.
+// TabContents to swap in the new renderer and destroy the old one.
void CrossSiteResourceHandler::ResumeResponse() {
DCHECK(request_id_ != -1);